==> lazerpay-python-sdk-0.1.tar.gz: lazerpay-python-sdk-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'lazerpay-python-sdk',         # How you named your package folder (MyLib)
  packages = ['lazerpay'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'API Wrapper for LazerPay',   # Give a short description about your library
  author = 'John Shodipo',                   # Type in your name
  author_email = 'newtonjohn043@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/johnkayode/lazerpay-python-sdk',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Johnkayode/lazerpay-python-sdk/archive/refs/tags/v_01.tar.gz',    # I explain this later on
  keywords = ['lazerpay', 'python', 'crypto'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> lazerpay-python-sdk-0.2.tar.gz: lazerpay-python-sdk-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'lazerpay-python-sdk',         # How you named your package folder (MyLib)
  packages = ['lazerpay','lazerpay.utils'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'API Wrapper for LazerPay',   # Give a short description about your library
  author = 'John Shodipo',                   # Type in your name
  author_email = 'newtonjohn043@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/johnkayode/lazerpay-python-sdk',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Johnkayode/lazerpay-python-sdk/archive/refs/tags/v_02.zip',    # I explain this later on
  keywords = ['lazerpay', 'python', 'crypto'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
